# Change log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/).


1.0.0 - 2016-01-04
------------------

First release!
